==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Parës Figurash</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Parësi i figurave është një mjet parjesh figurash me ndërfaqe të hijshme dhe funksionim të rrjedhshëm.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Figura</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Të dhëna elementare</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Kjo kartelë përmban shumë faqe, ju lutemi, përdorni Evince-n që të shihni krejt faqet.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Hap Drejtori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>S’keni leje të shihni figurën</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>S’u gjet kartelë figure</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datë kur u ndryshua</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Përmasë</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Madhësi kartele</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datë bërjeje</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mënyra e ekspozimit</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozimi</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Kohëzgjatje ekspozimi</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blic</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Hapje</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Rreze vatrore</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Hapje maksimum</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mënyrë matjeje</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balancë e së bardhës</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompensim blici</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model thjerre</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Hapësirë ngjyrash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Përmasa</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiketë</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Pa ripërmasim</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Përshtatja faqen figurës</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Përshtatja figurën faqes</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Ripërmasoje në:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milimetra</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centimetra</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Inç</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Pozicion Figure</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Ripërmasim</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Rregullime Figurash</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Rregullime Figurash</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Grila</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Këmbyes</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Rrëshqitje</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Unazë</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd/MM/yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Jepni emër të ri</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Përzgjidhni Drejtori</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Njëkohësimi në këtë drejtori është i çaktivizuar</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Shtoni dosje</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Administrim Njëkohësimesh Drejtorie</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Lista e drejtorisë është e zbrazët</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Anuloje njëkohësimin</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Figura</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Pajisja është hequr</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Kjo drejtori s’ekziston më</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Po llogaritet…</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Parje Figurash</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Pamje</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Përfundoje shfaqjen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hiqe nga albumi</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Skena e mëparshme</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Skena pasuese</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album i ri</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra sa krejt ekrani</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zmadhoje</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zvogëloje</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Ju lutemi, jepni shkurtore të re</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Shkurtore</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Shihni Foto</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Rikthe Parazgjedhjet</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Pamje</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Përfundoje shfaqjen</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtype</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hiqe nga albumi</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album i ri</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pushoje</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Luaje</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Rregullime Diapozitivash</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Këmbeni efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kohëzgjatje</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Këmbeni kohëzgjatje</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekondë</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>E parapëlqyera ime</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Madhësi 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sa ta nxërë dritarja</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Administrim figurash</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>E parapëlqyera ime</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Madhësi 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sa ta nxërë dritarja</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>S’u gjetën kartela figurash</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Hap Figurë</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>S’u gjet kartelë figure</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Rregullime Diapozitivash</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kohëzgjatje</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Shkurtore</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Shiheni</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Album i ri</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Rrjedhë kohore</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Shtojeni në album</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Shtoje në album të ri</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra sa krejt ekrani</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtype</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hiqe nga albumi</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Shfaq dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Fshih dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Hap Figurë</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Krejt figurat</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Vizatoni</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.16.orig.tar.xz: deepin-image-viewer-5.9.16/src/translations/deepin-image-viewer_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>S’u gjet kartelë figure</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Hap Figurë</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Parje Figurash</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Rregullime</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra “Sa krejt ekrani”</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Përfto tekstin</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Hollësi figure</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Zmadhoje</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Zvogëloje</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Hape</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Shfaq shkurtore</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Parës Figurash</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Parësi i figurave është një mjet parjesh figurash me ndërfaqe të hijshme dhe funksionim të rrjedhshëm.</translation>
    </message>
</context>
</TS>
